Index: wp-includes/plugin.php
===================================================================
--- wp-includes/plugin.php	(revision 18631)
+++ wp-includes/plugin.php	(working copy)
@@ -251,7 +251,7 @@
  * @param string $tag The filter hook to which the function to be removed is hooked.
  * @param callback $function_to_remove The name of the function which should be removed.
  * @param int $priority optional. The priority of the function (default: 10).
- * @param int $accepted_args optional. The number of arguments the function accpets (default: 1).
+ * @param int $accepted_args optional. The number of arguments the function accepts (default: 1).
  * @return boolean Whether the function existed before it was removed.
  */
 function remove_filter($tag, $function_to_remove, $priority = 10, $accepted_args = 1) {
@@ -520,7 +520,7 @@
  * @param string $tag The action hook to which the function to be removed is hooked.
  * @param callback $function_to_remove The name of the function which should be removed.
  * @param int $priority optional The priority of the function (default: 10).
- * @param int $accepted_args optional. The number of arguments the function accpets (default: 1).
+ * @param int $accepted_args optional. The number of arguments the function accepts (default: 1).
  * @return boolean Whether the function is removed.
  */
 function remove_action($tag, $function_to_remove, $priority = 10, $accepted_args = 1) {
@@ -745,7 +745,7 @@
  * @param string $tag Used in counting how many hooks were applied
  * @param callback $function Used for creating unique id
  * @param int|bool $priority Used in counting how many hooks were applied.  If === false and $function is an object reference, we return the unique id only if it already has one, false otherwise.
- * @return string|bool Unique ID for usage as array key or false if $priority === false and $function is an object reference, and it does not already have a uniqe id.
+ * @return string|bool Unique ID for usage as array key or false if $priority === false and $function is an object reference, and it does not already have a unique id.
  */
 function _wp_filter_build_unique_id($tag, $function, $priority) {
 	global $wp_filter;
Index: wp-includes/locale.php
===================================================================
--- wp-includes/locale.php	(revision 18631)
+++ wp-includes/locale.php	(working copy)
@@ -65,7 +65,7 @@
 	/**
 	 * Stores the translated strings for 'am' and 'pm'.
 	 *
-	 * Also the capalized versions.
+	 * Also the capitalized versions.
 	 *
 	 * @since 2.1.0
 	 * @var array
Index: wp-includes/taxonomy.php
===================================================================
--- wp-includes/taxonomy.php	(revision 18631)
+++ wp-includes/taxonomy.php	(working copy)
@@ -266,7 +266,7 @@
  * query_var - false to prevent queries, or string to customize query var
  * (?$query_var=$term); default will use $taxonomy as query var.
  *
- * public - If the taxonomy should be publically queryable; //@TODO not implemented.
+ * public - If the taxonomy should be publicly queryable; //@TODO not implemented.
  * defaults to true.
  *
  * show_ui - If the WordPress UI admin tags UI should apply to this taxonomy;
@@ -276,7 +276,7 @@
  * Defaults to public.
  *
  * show_tagcloud - false to prevent the taxonomy being listed in the Tag Cloud Widget;
- * defaults to show_ui which defalts to public.
+ * defaults to show_ui which defaults to public.
  *
  * labels - An array of labels for this taxonomy. You can see accepted values in {@link get_taxonomy_labels()}. By default tag labels are used for non-hierarchical types and category labels for hierarchical ones.
  *
@@ -369,7 +369,7 @@
  * Builds an object with all taxonomy labels out of a taxonomy object
  *
  * Accepted keys of the label array in the taxonomy object:
- * - name - general name for the taxonomy, usually plural. The same as and overriden by $tax->label. Default is Post Tags/Categories
+ * - name - general name for the taxonomy, usually plural. The same as and overridden by $tax->label. Default is Post Tags/Categories
  * - singular_name - name for one object of this taxonomy. Default is Post Tag/Category
  * - search_items - Default is Search Tags/Search Categories
  * - popular_items - This string isn't used on hierarchical taxonomies. Default is Popular Tags
@@ -1496,7 +1496,7 @@
 /**
  * Sanitize Term all fields.
  *
- * Relys on sanitize_term_field() to sanitize the term. The difference is that
+ * Relies on sanitize_term_field() to sanitize the term. The difference is that
  * this function will sanitize <strong>all</strong> fields. The context is based
  * on sanitize_term_field().
  *
@@ -1785,7 +1785,7 @@
  * @uses wp_delete_term()
  *
  * @param int $cat_ID
- * @return mixed Returns true if completes delete action; false if term doesnt exist;
+ * @return mixed Returns true if completes delete action; false if term doesn't exist;
  * 	Zero on attempted deletion of default Category; WP_Error object is also a possibility.
  */
 function wp_delete_category( $cat_ID ) {
@@ -1810,7 +1810,7 @@
  * 'all_with_object_id'.
  *
  * The fields argument also decides what will be returned. If 'all' or
- * 'all_with_object_id' is choosen or the default kept intact, then all matching
+ * 'all_with_object_id' is chosen or the default kept intact, then all matching
  * terms objects will be returned. If either 'ids' or 'names' is used, then an
  * array of all matching term ids or term names will be returned respectively.
  *
@@ -1918,7 +1918,7 @@
 /**
  * Adds a new term to the database. Optionally marks it as an alias of an existing term.
  *
- * Error handling is assigned for the nonexistance of the $taxonomy and $term
+ * Error handling is assigned for the nonexistence of the $taxonomy and $term
  * parameters before inserting. If both the term id and taxonomy exist
  * previously, then an array will be returned that contains the term id and the
  * contents of what is returned. The keys of the array are 'term_id' and
@@ -2179,7 +2179,7 @@
  * hierarchical and has a parent, it will append that parent to the $slug.
  *
  * If that still doesn't return an unique slug, then it try to append a number
- * until it finds a number that is truely unique.
+ * until it finds a number that is truly unique.
  *
  * The only purpose for $term is for appending a parent, if one exists.
  *
@@ -2385,7 +2385,7 @@
 /**
  * Updates the amount of terms in taxonomy.
  *
- * If there is a taxonomy callback applyed, then it will be called for updating
+ * If there is a taxonomy callback applied, then it will be called for updating
  * the count.
  *
  * The default action is to count what the amount of terms have the relationship
Index: wp-includes/class-http.php
===================================================================
--- wp-includes/class-http.php	(revision 18631)
+++ wp-includes/class-http.php	(working copy)
@@ -222,7 +222,7 @@
 	/**
 	 * Dispatches a HTTP request to a supporting transport.
 	 *
-	 * Tests each transport in order to find a transport which matches the request arguements.
+	 * Tests each transport in order to find a transport which matches the request arguments.
 	 * Also caches the transport instance to be used later.
 	 *
 	 * The order for blocking requests is cURL, Streams, and finally Fsockopen.
@@ -631,7 +631,7 @@
 
 		$endDelay = time();
 
-		// If the delay is greater than the timeout then fsockopen should't be used, because it will
+		// If the delay is greater than the timeout then fsockopen shouldn't be used, because it will
 		// cause a long delay.
 		$elapseDelay = ($endDelay-$startDelay) > $r['timeout'];
 		if ( true === $elapseDelay )
@@ -915,7 +915,7 @@
 		else
 			$processedHeaders = WP_Http::processHeaders($meta['wrapper_data']);
 
-		// Streams does not provide an error code which we can use to see why the request stream stoped.
+		// Streams does not provide an error code which we can use to see why the request stream stopped.
 		// We can however test to see if a location header is present and return based on that.
 		if ( isset($processedHeaders['headers']['location']) && 0 !== $args['_redirection'] )
 			return new WP_Error('http_request_failed', __('Too many redirects.'));
@@ -1031,7 +1031,7 @@
 
 
 		// CURLOPT_TIMEOUT and CURLOPT_CONNECTTIMEOUT expect integers.  Have to use ceil since
-		// a value of 0 will allow an ulimited timeout.
+		// a value of 0 will allow an unlimited timeout.
 		$timeout = (int) ceil( $r['timeout'] );
 		curl_setopt( $handle, CURLOPT_CONNECTTIMEOUT, $timeout );
 		curl_setopt( $handle, CURLOPT_TIMEOUT, $timeout );
@@ -1679,7 +1679,7 @@
 	}
 
 	/**
-	 * What enconding the content used when it was compressed to send in the headers.
+	 * What encoding the content used when it was compressed to send in the headers.
 	 *
 	 * @since 2.8
 	 *
Index: wp-includes/post.php
===================================================================
--- wp-includes/post.php	(revision 18631)
+++ wp-includes/post.php	(working copy)
@@ -1155,7 +1155,7 @@
  * Builds an object with all post type labels out of a post type object
  *
  * Accepted keys of the label array in the post type object:
- * - name - general name for the post type, usually plural. The same and overriden by $post_type_object->label. Default is Posts/Pages
+ * - name - general name for the post type, usually plural. The same and overridden by $post_type_object->label. Default is Posts/Pages
  * - singular_name - name for one object of this post type. Default is Post/Page
  * - add_new - Default is Add New for both hierarchical and non-hierarchical types. When internationalizing this string, please use a {@link http://codex.wordpress.org/I18n_for_WordPress_Developers#Disambiguation_by_context gettext context} matching your post type. Example: <code>_x('Add New', 'product');</code>
  * - add_new_item - Default is Add New Post/Add New Page
@@ -1249,7 +1249,7 @@
  * 'excerpt', 'page-attributes', 'thumbnail', and 'custom-fields'.
  *
  * Additionally, the 'revisions' feature dictates whether the post type will store revisions,
- * and the 'comments' feature dicates whether the comments count will show on the edit screen.
+ * and the 'comments' feature dictates whether the comments count will show on the edit screen.
  *
  * @since 3.0.0
  * @param string $post_type The post type for which to add the feature
@@ -3269,7 +3269,7 @@
 
 /**
  * function to traverse and return all the nested children post names of a root page.
- * $children contains parent-chilren relations
+ * $children contains parent-children relations
  *
  * @since 2.9.0
  */
@@ -3911,7 +3911,7 @@
 		}
 	}
 
-	if ( empty($url) ) //If any of the above options failed, Fallback on the GUID as used pre-2.7, not recomended to rely upon this.
+	if ( empty($url) ) //If any of the above options failed, Fallback on the GUID as used pre-2.7, not recommended to rely upon this.
 		$url = get_the_guid( $post->ID );
 
 	$url = apply_filters( 'wp_get_attachment_url', $url, $post->ID );
@@ -4466,7 +4466,7 @@
 /**
  * Will clean the attachment in the cache.
  *
- * Cleaning means delete from the cache. Optionaly will clean the term
+ * Cleaning means delete from the cache. Optionally will clean the term
  * object cache associated with the attachment ID.
  *
  * This function will not run if $_wp_suspend_cache_invalidation is not empty. See
@@ -4664,7 +4664,7 @@
  * Determines which fields of posts are to be saved in revisions.
  *
  * Does two things. If passed a post *array*, it will return a post array ready
- * to be insterted into the posts table as a post revision. Otherwise, returns
+ * to be inserted into the posts table as a post revision. Otherwise, returns
  * an array whose keys are the post fields to be saved for post revisions.
  *
  * @package WordPress
Index: wp-includes/js/tinymce/plugins/wpdialogs/js/popup.dev.js
===================================================================
--- wp-includes/js/tinymce/plugins/wpdialogs/js/popup.dev.js	(revision 18631)
+++ wp-includes/js/tinymce/plugins/wpdialogs/js/popup.dev.js	(working copy)
@@ -67,7 +67,7 @@
 	 * Returns a window argument/parameter by name.
 	 *
 	 * @method getWindowArg
-	 * @param {String} n Name of the window argument to retrive.
+	 * @param {String} n Name of the window argument to retrieve.
 	 * @param {String} dv Optional default value to return.
 	 * @return {String} Argument value or default value if it wasn't found.
 	 */
@@ -81,7 +81,7 @@
 	 * Returns a editor parameter/config option value.
 	 *
 	 * @method getParam
-	 * @param {String} n Name of the editor config option to retrive.
+	 * @param {String} n Name of the editor config option to retrieve.
 	 * @param {String} dv Optional default value to return.
 	 * @return {String} Parameter value or default value if it wasn't found.
 	 */
Index: wp-includes/theme.php
===================================================================
--- wp-includes/theme.php	(revision 18631)
+++ wp-includes/theme.php	(working copy)
@@ -469,7 +469,7 @@
  *
  * @since 2.9.0
  *
- * @return array|string An arry of theme roots keyed by template/stylesheet or a single theme root if all themes have the same root.
+ * @return array|string An array of theme roots keyed by template/stylesheet or a single theme root if all themes have the same root.
  */
 function get_theme_roots() {
 	global $wp_theme_directories;
Index: wp-includes/functions.php
===================================================================
--- wp-includes/functions.php	(revision 18631)
+++ wp-includes/functions.php	(working copy)
@@ -20,7 +20,7 @@
  * @param string $dateformatstring Either 'G', 'U', or php date format.
  * @param string $mysqlstring Time from mysql DATETIME field.
  * @param bool $translate Optional. Default is true. Will switch format to locale.
- * @return string Date formated by $dateformatstring or locale (if available).
+ * @return string Date formatted by $dateformatstring or locale (if available).
  */
 function mysql2date( $dateformatstring, $mysqlstring, $translate = true ) {
 	$m = $mysqlstring;
@@ -3586,7 +3586,7 @@
 		/* First we check if the DOMDocument class exists. If it does not exist,
 		 * which is the case for PHP 4.X, then we cannot easily update the xml configuration file,
 		 * hence we just bail out and tell user that pretty permalinks cannot be used.
-		 * This is not a big issue because PHP 4.X is going to be depricated and for IIS it
+		 * This is not a big issue because PHP 4.X is going to be deprecated and for IIS it
 		 * is recommended to use PHP 5.X NTS.
 		 * Next we check if the URL Rewrite Module 1.1 is loaded and enabled for the web site. When
 		 * URL Rewrite 1.1 is loaded it always sets a server variable called 'IIS_UrlRewriteModule'.
Index: wp-includes/l10n.php
===================================================================
--- wp-includes/l10n.php	(revision 18631)
+++ wp-includes/l10n.php	(working copy)
@@ -398,7 +398,7 @@
  * @param string $domain Unique identifier for retrieving translated strings
  * @param string $abs_rel_path Optional. Relative path to ABSPATH of a folder,
  * 	where the .mo file resides. Deprecated, but still functional until 2.7
- * @param string $plugin_rel_path Optional. Relative path to WP_PLUGIN_DIR. This is the preferred argument to use. It takes precendence over $abs_rel_path
+ * @param string $plugin_rel_path Optional. Relative path to WP_PLUGIN_DIR. This is the preferred argument to use. It takes precedence over $abs_rel_path
  */
 function load_plugin_textdomain( $domain, $abs_rel_path = false, $plugin_rel_path = false ) {
 	$locale = apply_filters( 'plugin_locale', get_locale(), $domain );
@@ -532,4 +532,4 @@
 	}
 
 	return $languages;
-}
\ No newline at end of file
+}
Index: wp-includes/comment-template.php
===================================================================
--- wp-includes/comment-template.php	(revision 18631)
+++ wp-includes/comment-template.php	(working copy)
@@ -362,7 +362,7 @@
  * Retrieve the comment date of the current comment.
  *
  * @since 1.5.0
- * @uses apply_filters() Calls 'get_comment_date' hook with the formated date and the $d parameter respectively
+ * @uses apply_filters() Calls 'get_comment_date' hook with the formatted date and the $d parameter respectively
  * @uses $comment
  *
  * @param string $d The format of the date (defaults to user's config)
@@ -832,7 +832,7 @@
  *
  * The $file path is passed through a filter hook called, 'comments_template'
  * which includes the TEMPLATEPATH and $file combined. Tries the $filtered path
- * first and if it fails it will require the default comment themplate from the
+ * first and if it fails it will require the default comment template from the
  * default theme. If either does not exist, then the WordPress process will be
  * halted. It is advised for that reason, that the default theme is not deleted.
  *
Index: wp-includes/shortcodes.php
===================================================================
--- wp-includes/shortcodes.php	(revision 18631)
+++ wp-includes/shortcodes.php	(working copy)
@@ -157,7 +157,7 @@
  * The regular expression combines the shortcode tags in the regular expression
  * in a regex class.
  *
- * The regular expresion contains 6 different sub matches to help with parsing.
+ * The regular expression contains 6 different sub matches to help with parsing.
  *
  * 1/6 - An extra [ or ] to allow for escaping shortcodes with double [[]]
  * 2 - The shortcode name
@@ -295,4 +295,4 @@
 
 add_filter('the_content', 'do_shortcode', 11); // AFTER wpautop()
 
-?>
\ No newline at end of file
+?>
Index: wp-includes/user.php
===================================================================
--- wp-includes/user.php	(revision 18631)
+++ wp-includes/user.php	(working copy)
@@ -1444,7 +1444,7 @@
  * A simpler way of inserting an user into the database.
  *
  * Creates a new user with just the username, password, and email. For a more
- * detail creation of a user, use wp_insert_user() to specify more infomation.
+ * detail creation of a user, use wp_insert_user() to specify more information.
  *
  * @since 2.0.0
  * @see wp_insert_user() More complete way to create a new user
Index: wp-includes/media.php
===================================================================
--- wp-includes/media.php	(revision 18631)
+++ wp-includes/media.php	(working copy)
@@ -260,7 +260,7 @@
 }
 
 /**
- * Calculates the new dimentions for a downsampled image.
+ * Calculates the new dimensions for a downsampled image.
  *
  * If either width or height are empty, no constraint is applied on
  * that dimension.
@@ -305,7 +305,7 @@
 	$h = intval( $current_height * $ratio );
 
 	// Sometimes, due to rounding, we'll end up with a result like this: 465x700 in a 177x177 box is 117x176... a pixel short
-	// We also have issues with recursive calls resulting in an ever-changing result. Contraining to the result of a constraint should yield the original result.
+	// We also have issues with recursive calls resulting in an ever-changing result. Constraining to the result of a constraint should yield the original result.
 	// Thus we look for dimensions that are one pixel shy of the max value and bump them up
 	if ( $did_width && $w == $max_width - 1 )
 		$w = $max_width; // Round it up
@@ -1144,7 +1144,7 @@
 	 * @uses update_post_meta()
 	 *
 	 * @param array $attr Shortcode attributes.
-	 * @param string $url The URL attempting to be embeded.
+	 * @param string $url The URL attempting to be embedded.
 	 * @return string The embed HTML on success, otherwise the original URL.
 	 */
 	function shortcode( $attr, $url = '' ) {
@@ -1372,7 +1372,7 @@
  * @uses _wp_oembed_get_object()
  * @uses WP_oEmbed::get_html()
  *
- * @param string $url The URL that should be embeded.
+ * @param string $url The URL that should be embedded.
  * @param array $args Addtional arguments and parameters.
  * @return string The original URL on failure or the embed HTML on success.
  */
@@ -1438,4 +1438,4 @@
 	return apply_filters( 'embed_googlevideo', '<embed type="application/x-shockwave-flash" src="http://video.google.com/googleplayer.swf?docid=' . esc_attr($matches[2]) . '&amp;hl=en&amp;fs=true" style="width:' . esc_attr($width) . 'px;height:' . esc_attr($height) . 'px" allowFullScreen="true" allowScriptAccess="always" />', $matches, $attr, $url, $rawattr );
 }
 
-?>
\ No newline at end of file
+?>
Index: wp-includes/class-wp-xmlrpc-server.php
===================================================================
--- wp-includes/class-wp-xmlrpc-server.php	(revision 18631)
+++ wp-includes/class-wp-xmlrpc-server.php	(working copy)
@@ -8,7 +8,7 @@
 /**
  * WordPress XMLRPC server implementation.
  *
- * Implements compatability for Blogger API, MetaWeblog API, MovableType, and
+ * Implements compatibility for Blogger API, MetaWeblog API, MovableType, and
  * pingback. Additional WordPress API for managing comments, pages, posts,
  * options, etc.
  *
@@ -747,7 +747,7 @@
 			ORDER BY ID
 		");
 
-		// The date needs to be formated properly.
+		// The date needs to be formatted properly.
 		$num_pages = count($page_list);
 		for ( $i = 0; $i < $num_pages; $i++ ) {
 			$post_date = mysql2date('Ymd\TH:i:s', $page_list[$i]->post_date, false);
@@ -1551,7 +1551,7 @@
 	 *  - username
 	 *  - password
 	 *  - attachment_id
-	 * @return array. Assocciative array containing:
+	 * @return array. Associative array containing:
 	 *  - 'date_created_gmt'
 	 *  - 'parent'
 	 *  - 'link'
@@ -1661,7 +1661,7 @@
 	}
 
 	/**
-	  * Retrives a list of post formats used by the site
+	  * Retrieves a list of post formats used by the site
 	  *
 	  * @since 3.1
 	  *
@@ -3445,7 +3445,7 @@
 		} elseif ( isset($urltest['fragment']) ) {
 			// an #anchor is there, it's either...
 			if ( intval($urltest['fragment']) ) {
-				// ...an integer #XXXX (simpliest case)
+				// ...an integer #XXXX (simplest case)
 				$post_ID = (int) $urltest['fragment'];
 				$way = 'from the fragment (numeric)';
 			} elseif ( preg_match('/post-[0-9]+/',$urltest['fragment']) ) {
Index: wp-includes/class-phpass.php
===================================================================
--- wp-includes/class-phpass.php	(revision 18631)
+++ wp-includes/class-phpass.php	(working copy)
@@ -49,7 +49,7 @@
 
 		$this->portable_hashes = $portable_hashes;
 
-		$this->random_state = microtime() . uniqid(rand(), TRUE); // removed getmypid() for compability reasons
+		$this->random_state = microtime() . uniqid(rand(), TRUE); // removed getmypid() for compatibility reasons
 	}
 
 	function get_random_bytes($count)
Index: wp-includes/cache.php
===================================================================
--- wp-includes/cache.php	(revision 18631)
+++ wp-includes/cache.php	(working copy)
@@ -9,7 +9,7 @@
  */
 
 /**
- * Adds data to the cache, if the cache key doesn't aleady exist.
+ * Adds data to the cache, if the cache key doesn't already exist.
  *
  * @since 2.0.0
  * @uses $wp_object_cache Object Cache Class
@@ -31,7 +31,7 @@
  * Closes the cache.
  *
  * This function has ceased to do anything since WordPress 2.5. The
- * functionality was removed along with the rest of the persistant cache. This
+ * functionality was removed along with the rest of the persistent cache. This
  * does not mean that plugins can't implement this function when they need to
  * make sure that the cache is cleaned up after WordPress no longer needs it.
  *
@@ -282,7 +282,7 @@
 	 *
 	 * @uses WP_Object_Cache::get Checks to see if the cache already has data.
 	 * @uses WP_Object_Cache::set Sets the data after the checking the cache
-	 *		contents existance.
+	 *		contents existence.
 	 *
 	 * @since 2.0.0
 	 *
Index: wp-includes/query.php
===================================================================
--- wp-includes/query.php	(revision 18631)
+++ wp-includes/query.php	(working copy)
@@ -2137,7 +2137,7 @@
 		if ( intval($q['comments_popup']) )
 			$q['p'] = absint($q['comments_popup']);
 
-		// If an attachment is requested by number, let it supercede any post number.
+		// If an attachment is requested by number, let it supersede any post number.
 		if ( $q['attachment_id'] )
 			$q['p'] = absint($q['attachment_id']);
 
@@ -2288,7 +2288,7 @@
 				if ( $q['author_name'][ count($q['author_name'])-1 ] ) {
 					$q['author_name'] = $q['author_name'][count($q['author_name'])-1]; // no trailing slash
 				} else {
-					$q['author_name'] = $q['author_name'][count($q['author_name'])-2]; // there was a trailling slash
+					$q['author_name'] = $q['author_name'][count($q['author_name'])-2]; // there was a trailing slash
 				}
 			}
 			$q['author_name'] = sanitize_title_for_query( $q['author_name'] );
Index: wp-includes/link-template.php
===================================================================
--- wp-includes/link-template.php	(revision 18631)
+++ wp-includes/link-template.php	(working copy)
@@ -2415,7 +2415,7 @@
 }
 
 /**
- *  Inject rel=sortlink into head if a shortlink is defined for the current page.
+ *  Inject rel=shortlink into head if a shortlink is defined for the current page.
  *
  *  Attached to the wp_head action.
  *
Index: wp-includes/wp-db.php
===================================================================
--- wp-includes/wp-db.php	(revision 18631)
+++ wp-includes/wp-db.php	(working copy)
@@ -640,7 +640,7 @@
 	 * Returns an array of WordPress tables.
 	 *
 	 * Also allows for the CUSTOM_USER_TABLE and CUSTOM_USER_META_TABLE to
-	 * override the WordPress users and usersmeta tables that would otherwise
+	 * override the WordPress users and usermeta tables that would otherwise
 	 * be determined by the prefix.
 	 *
 	 * The scope argument can take one of the following:
@@ -1289,7 +1289,7 @@
 	 * @param string $output Optional. one of ARRAY_A | ARRAY_N | OBJECT constants. Return an associative array (column => value, ...),
 	 * 	a numerically indexed array (0 => value, ...) or an object ( ->column = value ), respectively.
 	 * @param int $y Optional. Row to return. Indexed from 0.
-	 * @return mixed Database query result in format specifed by $output or null on failure
+	 * @return mixed Database query result in format specified by $output or null on failure
 	 */
 	function get_row( $query = null, $output = OBJECT, $y = 0 ) {
 		$this->func_call = "\$db->get_row(\"$query\",$output,$y)";
Index: wp-includes/formatting.php
===================================================================
--- wp-includes/formatting.php	(revision 18631)
+++ wp-includes/formatting.php	(working copy)
@@ -2228,7 +2228,7 @@
  * Checks and cleans a URL.
  *
  * A number of characters are removed from the URL. If the URL is for displaying
- * (the default behaviour) amperstands are also replaced. The 'clean_url' filter
+ * (the default behaviour) ampersands are also replaced. The 'clean_url' filter
  * is applied to the returned cleaned URL.
  *
  * @since 2.8.0
Index: wp-includes/author-template.php
===================================================================
--- wp-includes/author-template.php	(revision 18631)
+++ wp-includes/author-template.php	(working copy)
@@ -38,7 +38,7 @@
  * still use the old behavior will also pass the value from get_the_author().
  *
  * The normal, expected behavior of this function is to echo the author and not
- * return it. However, backwards compatiability has to be maintained.
+ * return it. However, backwards compatibility has to be maintained.
  *
  * @since 0.71
  * @see get_the_author()
Index: wp-includes/capabilities.php
===================================================================
--- wp-includes/capabilities.php	(revision 18631)
+++ wp-includes/capabilities.php	(working copy)
@@ -524,7 +524,7 @@
 	}
 
 	/**
-	 * Magic method for checking the existance of a certain custom field
+	 * Magic method for checking the existence of a certain custom field
 	 *
 	 * @since 3.3.0
 	 */
@@ -827,7 +827,7 @@
 	 *
 	 * This is useful for looking up whether the user has a specific role
 	 * assigned to the user. The second optional parameter can also be used to
-	 * check for capabilities against a specfic post.
+	 * check for capabilities against a specific post.
 	 *
 	 * @since 2.0.0
 	 * @access public
Index: wp-includes/class-wp.php
===================================================================
--- wp-includes/class-wp.php	(revision 18631)
+++ wp-includes/class-wp.php	(working copy)
@@ -569,7 +569,7 @@
 	 *
 	 * @access public
 	 * @param string $subject subject
-	 * @param array  $matches data used for subsitution
+	 * @param array  $matches data used for substitution
 	 * @return string
 	 */
 	function apply($subject, $matches) {
Index: wp-includes/class-oembed.php
===================================================================
--- wp-includes/class-oembed.php	(revision 18631)
+++ wp-includes/class-oembed.php	(working copy)
@@ -28,7 +28,7 @@
 	function __construct() {
 		// List out some popular sites that support oEmbed.
 		// The WP_Embed class disables discovery for non-unfiltered_html users, so only providers in this array will be used for them.
-		// Add to this list using the wp_oembed_add_provider() function (see it's PHPDoc for details).
+		// Add to this list using the wp_oembed_add_provider() function (see its PHPDoc for details).
 		$this->providers = apply_filters( 'oembed_providers', array(
 			'#http://(www\.)?youtube.com/watch.*#i'         => array( 'http://www.youtube.com/oembed',            true  ),
 			'http://youtu.be/*'                             => array( 'http://www.youtube.com/oembed',            false ),
@@ -292,4 +292,4 @@
 	return $wp_oembed;
 }
 
-?>
\ No newline at end of file
+?>
Index: wp-includes/deprecated.php
===================================================================
--- wp-includes/deprecated.php	(revision 18631)
+++ wp-includes/deprecated.php	(working copy)
@@ -2073,7 +2073,7 @@
  * Checks and cleans a URL.
  *
  * A number of characters are removed from the URL. If the URL is for displaying
- * (the default behaviour) amperstands are also replaced. The 'clean_url' filter
+ * (the default behaviour) ampersands are also replaced. The 'clean_url' filter
  * is applied to the returned cleaned URL.
  *
  * @since 1.2.0
Index: wp-includes/pluggable.php
===================================================================
--- wp-includes/pluggable.php	(revision 18631)
+++ wp-includes/pluggable.php	(working copy)
@@ -1086,7 +1086,7 @@
 	$comment = get_comment($comment_id);
 	$post = get_post($comment->comment_post_ID);
 	$user = get_userdata( $post->post_author );
-	// Send to the administation and to the post author if the author can modify the comment.
+	// Send to the administration and to the post author if the author can modify the comment.
 	$email_to = array( get_option('admin_email') );
 	if ( user_can($user->ID, 'edit_comment', $comment_id) && !empty($user->user_email) && ( get_option('admin_email') != $user->user_email) )
 		$email_to[] = $user->user_email;
@@ -1432,7 +1432,7 @@
  *
  * Maintains compatibility between old version and the new cookie authentication
  * protocol using PHPass library. The $hash parameter is the encrypted password
- * and the function compares the plain text password when encypted similarly
+ * and the function compares the plain text password when encrypted similarly
  * against the already encrypted password to see if they match.
  *
  * For integration with other applications, this function can be overwritten to
Index: wp-includes/widgets.php
===================================================================
--- wp-includes/widgets.php	(revision 18631)
+++ wp-includes/widgets.php	(working copy)
@@ -139,7 +139,7 @@
 		}
 
 		if ( $empty ) {
-			// If there are none, we register the widget's existance with a
+			// If there are none, we register the widget's existence with a
 			// generic template
 			$this->_set(1);
 			$this->_register_one();
@@ -297,7 +297,7 @@
 			$settings = array();
 
 		if ( !array_key_exists('_multiwidget', $settings) ) {
-			// old format, conver if single widget
+			// old format, convert if single widget
 			$settings = wp_convert_widget_settings($this->id_base, $this->option_name, $settings);
 		}
 
@@ -461,7 +461,7 @@
  * The default for the name is "Sidebar #", with '#' being replaced with the
  * number the sidebar is currently when greater than one. If first sidebar, the
  * name will be just "Sidebar". The default for id is "sidebar-" followed by the
- * number the sidebar creation is currently at. If the id is provided, and mutliple
+ * number the sidebar creation is currently at. If the id is provided, and multiple
  * sidebars are being defined, the id will have "-2" appended, and so on.
  *
  * @since 2.2.0
Index: wp-includes/script-loader.php
===================================================================
--- wp-includes/script-loader.php	(revision 18631)
+++ wp-includes/script-loader.php	(working copy)
@@ -159,7 +159,7 @@
 	if ( empty($max_upload_size) )
 		$max_upload_size = __('not configured');
 
-	// error messagoe for both plupload and swfupload
+	// error message for both plupload and swfupload
 	$uploader_l10n = array(
 		'queue_limit_exceeded' => __('You have attempted to queue too many files.'),
 		'file_exceeds_size_limit' => __('This file exceeds the maximum upload size for this site.'),
@@ -439,7 +439,7 @@
  *
  * @since 2.3.1
  *
- * @param array $js_array JavaScript scripst array
+ * @param array $js_array JavaScript scripts array
  * @return array Reordered array, if needed.
  */
 function wp_prototype_before_jquery( $js_array ) {
Index: wp-includes/http.php
===================================================================
--- wp-includes/http.php	(revision 18631)
+++ wp-includes/http.php	(working copy)
@@ -130,7 +130,7 @@
  *
  * @param array $response
  * @param string $header Header name to retrieve value from.
- * @return string The header value. Empty string on if incorrect parameter given, or if the header doesnt exist.
+ * @return string The header value. Empty string on if incorrect parameter given, or if the header doesn't exist.
  */
 function wp_remote_retrieve_header(&$response, $header) {
 	if ( is_wp_error($response) || ! isset($response['headers']) || ! is_array($response['headers']))
Index: wp-includes/class-wp-error.php
===================================================================
--- wp-includes/class-wp-error.php	(revision 18631)
+++ wp-includes/class-wp-error.php	(working copy)
@@ -70,7 +70,7 @@
 	 * @since 2.1.0
 	 * @access public
 	 *
-	 * @return array List of error codes, if avaiable.
+	 * @return array List of error codes, if available.
 	 */
 	function get_error_codes() {
 		if ( empty($this->errors) )
@@ -102,7 +102,7 @@
 	 * @since 2.1.0
 	 *
 	 * @param string|int $code Optional. Retrieve messages matching code, if exists.
-	 * @return array Error strings on success, or empty array on failure (if using codee parameter).
+	 * @return array Error strings on success, or empty array on failure (if using code parameter).
 	 */
 	function get_error_messages($code = '') {
 		// Return all messages if no code specified.
@@ -209,4 +209,4 @@
 	return false;
 }
 
-?>
\ No newline at end of file
+?>

Index: wp-includes/canonical.php
===================================================================
--- wp-includes/canonical.php	(revision 18631)
+++ wp-includes/canonical.php	(working copy)
@@ -14,7 +14,7 @@
  *
  * Search engines consider www.somedomain.com and somedomain.com to be two
  * different URLs when they both go to the same location. This SEO enhancement
- * prevents penality for duplicate content by redirecting all incoming links to
+ * prevents penalty for duplicate content by redirecting all incoming links to
  * one or the other.
  *
  * Prevents redirection for feeds, trackbacks, searches, comment popup, and
@@ -175,10 +175,10 @@
 
 						// Create the destination url for this taxonomy
 						$tax_url = parse_url($tax_url);
-						if ( ! empty($tax_url['query']) ) { // Taxonomy accessable via ?taxonomy=..&term=.. or any custom qv..
+						if ( ! empty($tax_url['query']) ) { // Taxonomy accessible via ?taxonomy=..&term=.. or any custom qv..
 							parse_str($tax_url['query'], $query_vars);
 							$redirect['query'] = add_query_arg($query_vars, $redirect['query']);
-						} else { // Taxonomy is accessable via a "pretty-URL"
+						} else { // Taxonomy is accessible via a "pretty-URL"
 							$redirect['path'] = $tax_url['path'];
 						}
 